@@ -528,6 +528,16 @@ impl_GetInterfaces (DBusConnection * bus,
   return reply;
 }
 
+static dbus_bool_t
+impl_get_AccessibleId (DBusMessageIter * iter, void *user_data)
+{
+  AtkObject *object = (AtkObject *) user_data;
+
+  g_return_val_if_fail (ATK_IS_OBJECT (user_data), FALSE);
+
+  return droute_return_v_string (iter, atk_object_get_accessible_id (object));
+}
+
 static DRouteMethod methods[] = {
   {impl_GetChildAtIndex, "GetChildAtIndex"},
   {impl_GetChildren, "GetChildren"},
@@ -550,6 +560,7 @@ static DRouteProperty properties[] = {
   {impl_get_Parent, NULL, "Parent"},
   {impl_get_ChildCount, NULL, "ChildCount"},
   {impl_get_Attributes, NULL, "Attributes"},
+  {impl_get_AccessibleId, NULL, "AccessibleId"},
   {NULL, NULL, NULL}
 };
 
